@@ -233,6 +233,9 @@ INVALIDPARAMETER_IMAGEIDSSNAPSHOTIDSMUSTONE = 'InvalidParameter.ImageIdsSnapshot
 # 当前接口不支持实例镜像。
 INVALIDPARAMETER_INSTANCEIMAGENOTSUPPORT = 'InvalidParameter.InstanceImageNotSupport'
 
+# 不支持设置公网带宽相关信息。
+INVALIDPARAMETER_INTERNETACCESSIBLENOTSUPPORTED = 'InvalidParameter.InternetAccessibleNotSupported'
+
 # 云盘资源售罄。
 INVALIDPARAMETER_INVALIDCLOUDDISKSOLDOUT = 'InvalidParameter.InvalidCloudDiskSoldOut'
 
@@ -743,6 +746,9 @@ UNSUPPORTEDOPERATION_INSTANCECHARGETYPE = 'UnsupportedOperation.InstanceChargeTy
 # 不支持混合付费模式。
 UNSUPPORTEDOPERATION_INSTANCEMIXEDPRICINGMODEL = 'UnsupportedOperation.InstanceMixedPricingModel'
 
+# 中心可用区和边缘可用区实例不能混用批量操作。
+UNSUPPORTEDOPERATION_INSTANCEMIXEDZONETYPE = 'UnsupportedOperation.InstanceMixedZoneType'
+
 # 请求不支持操作系统为`Xserver windows2012cndatacenterx86_64`的实例`ins-xxxxxx` 。
 UNSUPPORTEDOPERATION_INSTANCEOSWINDOWS = 'UnsupportedOperation.InstanceOsWindows'
 
